@@ -77,41 +77,6 @@ NULL
 
 }
 
-#' @noRd
-testSolver <- function(solver) {
-
-  obj   <- seq(.1, .5, .1)
-  mat   <- matrix(
-    c(1, 1, 1, 1, 1,
-      0, 0, 0, 1, 0),
-    2, 5,
-    byrow = TRUE)
-  dir   <- rep("==", 2)
-  rhs   <- c(2, 0)
-  types <- "B"
-
-  solver <- toupper(solver)
-  o <- try(
-    runMIP(
-      solver,
-      obj, mat, dir, rhs,
-      TRUE, types,
-      verbosity = -2,
-      time_limit = 5,
-      gap_limit_abs = 0.05,
-      gap_limit = 0.05
-    ),
-    silent = TRUE
-  )
-
-  if (inherits(o, "try-error")) {
-    return(trimws(as.character(o)))
-  }
-
-  return("")
-
-}
-
 setClassUnion("dataframe_or_null"   , c("data.frame"  , "NULL"))
 setClassUnion("character_or_null"   , c("character"   , "NULL"))
 setClassUnion("numeric_or_null"     , c("numeric"     , "NULL"))
